Index: include/asterisk/file.h
===================================================================
--- include/asterisk/file.h	(revision 90151)
+++ include/asterisk/file.h	(working copy)
@@ -132,7 +132,7 @@
 	FILE *f;
 	struct ast_frame fr;	/* frame produced by read, typically */
 	char *buf;		/* buffer pointed to by ast_frame; */
-	void *private;	/* pointer to private buffer */
+	void *_private;	/* pointer to private buffer */
 	const char *orig_chan_name;
 };
 
Index: main/file.c
===================================================================
--- main/file.c	(revision 90151)
+++ main/file.c	(working copy)
@@ -299,7 +299,7 @@
 	s->f = bfile;
 
 	if (fmt->desc_size)
-		s->private = ((char *)(s+1)) + fmt->buf_size;
+		s->_private = ((char *)(s+1)) + fmt->buf_size;
 	if (fmt->buf_size)
 		s->buf = (char *)(s+1);
 	s->fr.src = fmt->name;
Index: formats/format_wav.c
===================================================================
--- formats/format_wav.c	(revision 90151)
+++ formats/format_wav.c	(working copy)
@@ -324,7 +324,7 @@
 	/* We don't have any header to read or anything really, but
 	   if we did, it would go here.  We also might want to check
 	   and be sure it's a valid file.  */
-	struct wav_desc *tmp = (struct wav_desc *)s->private;
+	struct wav_desc *tmp = (struct wav_desc *)s->_private;
 	if ((tmp->maxlen = check_header(s->f)) < 0)
 		return -1;
 	return 0;
@@ -344,7 +344,7 @@
 static void wav_close(struct ast_filestream *s)
 {
 	char zero = 0;
-	struct wav_desc *fs = (struct wav_desc *)s->private;
+	struct wav_desc *fs = (struct wav_desc *)s->_private;
 	/* Pad to even length */
 	if (fs->bytes & 0x1)
 		fwrite(&zero, 1, 1, s->f);
@@ -359,7 +359,7 @@
 	int bytes = WAV_BUF_SIZE;	/* in bytes */
 	off_t here;
 	/* Send a frame from the file to the appropriate channel */
-	struct wav_desc *fs = (struct wav_desc *)s->private;
+	struct wav_desc *fs = (struct wav_desc *)s->_private;
 
 	here = ftello(s->f);
 	if (fs->maxlen - here < bytes)		/* truncate if necessary */
@@ -411,7 +411,7 @@
 	int x;
 	short tmp[8000], *tmpi;
 	float tmpf;
-	struct wav_desc *s = (struct wav_desc *)fs->private;
+	struct wav_desc *s = (struct wav_desc *)fs->_private;
 	int res;
 
 	if (f->frametype != AST_FRAME_VOICE) {
Index: formats/format_ogg_vorbis.c
===================================================================
--- formats/format_ogg_vorbis.c	(revision 90151)
+++ formats/format_ogg_vorbis.c	(working copy)
@@ -99,7 +99,7 @@
 	int result;
 	char **ptr;
 	char *buffer;
-	struct vorbis_desc *tmp = (struct vorbis_desc *)s->private;
+	struct vorbis_desc *tmp = (struct vorbis_desc *)s->_private;
 
 	tmp->writing = 0;
 
@@ -209,7 +209,7 @@
 	ogg_packet header;
 	ogg_packet header_comm;
 	ogg_packet header_code;
-	struct vorbis_desc *tmp = (struct vorbis_desc *)s->private;
+	struct vorbis_desc *tmp = (struct vorbis_desc *)s->_private;
 
 	tmp->writing = 1;
 
@@ -286,7 +286,7 @@
 	int i;
 	float **buffer;
 	short *data;
-	struct vorbis_desc *s = (struct vorbis_desc *)fs->private;
+	struct vorbis_desc *s = (struct vorbis_desc *)fs->_private;
 
 	if (!s->writing) {
 		ast_log(LOG_ERROR, "This stream is not set up for writing!\n");
@@ -325,7 +325,7 @@
  */
 static void ogg_vorbis_close(struct ast_filestream *fs)
 {
-	struct vorbis_desc *s = (struct vorbis_desc *)fs->private;
+	struct vorbis_desc *s = (struct vorbis_desc *)fs->_private;
 
 	if (s->writing) {
 		/* Tell the Vorbis encoder that the stream is finished
@@ -357,7 +357,7 @@
 	int result;
 	char *buffer;
 	int bytes;
-	struct vorbis_desc *s = (struct vorbis_desc *)fs->private;
+	struct vorbis_desc *s = (struct vorbis_desc *)fs->_private;
 
 	while (1) {
 		samples_in = vorbis_synthesis_pcmout(&s->vd, pcm);
@@ -440,7 +440,7 @@
 	int val;
 	int samples_in;
 	int samples_out = 0;
-	struct vorbis_desc *s = (struct vorbis_desc *)fs->private;
+	struct vorbis_desc *s = (struct vorbis_desc *)fs->_private;
 	short *buf;	/* SLIN data buffer */
 
 	fs->fr.frametype = AST_FRAME_VOICE;
Index: formats/format_wav_gsm.c
===================================================================
--- formats/format_wav_gsm.c	(revision 90151)
+++ formats/format_wav_gsm.c	(working copy)
@@ -383,7 +383,7 @@
 	/* We don't have any header to read or anything really, but
 	   if we did, it would go here.  We also might want to check
 	   and be sure it's a valid file.  */
-	struct wavg_desc *fs = (struct wavg_desc *)s->private;
+	struct wavg_desc *fs = (struct wavg_desc *)s->_private;
 
 	if (check_header(s->f))
 		return -1;
@@ -414,7 +414,7 @@
 static struct ast_frame *wav_read(struct ast_filestream *s, int *whennext)
 {
 	/* Send a frame from the file to the appropriate channel */
-	struct wavg_desc *fs = (struct wavg_desc *)s->private;
+	struct wavg_desc *fs = (struct wavg_desc *)s->_private;
 
 	s->fr.frametype = AST_FRAME_VOICE;
 	s->fr.subclass = AST_FORMAT_GSM;
@@ -448,7 +448,7 @@
 {
 	int len;
 	int size;
-	struct wavg_desc *fs = (struct wavg_desc *)s->private;
+	struct wavg_desc *fs = (struct wavg_desc *)s->_private;
 
 	if (f->frametype != AST_FRAME_VOICE) {
 		ast_log(LOG_WARNING, "Asked to write non-voice frame!\n");
@@ -494,7 +494,7 @@
 static int wav_seek(struct ast_filestream *fs, off_t sample_offset, int whence)
 {
 	off_t offset=0, distance, max;
-	struct wavg_desc *s = (struct wavg_desc *)fs->private;
+	struct wavg_desc *s = (struct wavg_desc *)fs->_private;
 
 	off_t min = MSGSM_DATA_OFFSET;
 	off_t cur = ftello(fs->f);
Index: formats/format_pcm.c
===================================================================
--- formats/format_pcm.c	(revision 90151)
+++ formats/format_pcm.c	(working copy)
@@ -180,7 +180,7 @@
 
 #ifdef REALTIME_WRITE
 	if (s->fmt->format == AST_FORMAT_ALAW) {
-		struct pcm_desc *pd = (struct pcm_desc *)fs->private;
+		struct pcm_desc *pd = (struct pcm_desc *)fs->_private;
 		struct stat stat_buf;
 		unsigned long cur_time = get_time();
 		unsigned long fpos = ( cur_time - pd->start_time ) * 8;	/* 8 bytes per msec */
Index: formats/format_h263.c
===================================================================
--- formats/format_h263.c	(revision 90151)
+++ formats/format_h263.c	(working copy)
@@ -80,7 +80,7 @@
 	int mark;
 	unsigned short len;
 	unsigned int ts;
-	struct h263_desc *fs = (struct h263_desc *)s->private;
+	struct h263_desc *fs = (struct h263_desc *)s->_private;
 
 	/* Send a frame from the file to the appropriate channel */
 	if ((res = fread(&len, 1, sizeof(len), s->f)) < 1)
Index: formats/format_h264.c
===================================================================
--- formats/format_h264.c	(revision 90151)
+++ formats/format_h264.c	(working copy)
@@ -72,7 +72,7 @@
 	int mark=0;
 	unsigned short len;
 	unsigned int ts;
-	struct h264_desc *fs = (struct h264_desc *)s->private;
+	struct h264_desc *fs = (struct h264_desc *)s->_private;
 
 	/* Send a frame from the file to the appropriate channel */
 	if ((res = fread(&len, 1, sizeof(len), s->f)) < 1)
Index: formats/format_g726.c
===================================================================
--- formats/format_g726.c	(revision 90151)
+++ formats/format_g726.c	(working copy)
@@ -76,7 +76,7 @@
  */
 static int g726_open(struct ast_filestream *tmp, int rate)
 {
-	struct g726_desc *s = (struct g726_desc *)tmp->private;
+	struct g726_desc *s = (struct g726_desc *)tmp->_private;
 	s->rate = rate;
 	if (option_debug)
 		ast_log(LOG_DEBUG, "Created filestream G.726-%dk.\n", 
@@ -131,7 +131,7 @@
 static struct ast_frame *g726_read(struct ast_filestream *s, int *whennext)
 {
 	int res;
-	struct g726_desc *fs = (struct g726_desc *)s->private;
+	struct g726_desc *fs = (struct g726_desc *)s->_private;
 
 	/* Send a frame from the file to the appropriate channel */
 	s->fr.frametype = AST_FRAME_VOICE;
@@ -151,7 +151,7 @@
 static int g726_write(struct ast_filestream *s, struct ast_frame *f)
 {
 	int res;
-	struct g726_desc *fs = (struct g726_desc *)s->private;
+	struct g726_desc *fs = (struct g726_desc *)s->_private;
 
 	if (f->frametype != AST_FRAME_VOICE) {
 		ast_log(LOG_WARNING, "Asked to write non-voice frame!\n");
